@@ -30,8 +30,8 @@ def main(input_filepath, output_filepath, model_name):
         data = []
         csv = []
         with open(file_path, 'r') as file:
-            for line in tqdm(file.readlines(), position=1, leave=True, desc='file parsing'):
-                if len(line) > 10:
+            for line in tqdm(file.readlines(), position=1, leave=False, desc='file parsing'):
+                if len(line) > 5 and len(line.split(' ')) > 10:
                     line = re.sub('[ \n]', '', line).strip().lower()
                     tokens = tokenizer.encode(line, truncation=True,
                                               add_special_tokens=False,
